#Go to apps.twitter.com.  Create a new app and use those credentials for your consumer key and secret
#after you've create a new app, you can generate an access token and secret for your account/app

CONSUMER_KEY='Your Consumer Key'
CONSUMER_SECRET='Your Consumer Secret'

ACCESS_TOKEN='Your access token'
ACCESS_TOKEN_SECRET='Your secret access token'




from env import *
import twitter
import pprint
import random
import time
from multiprocessing import Process

api = twitter.Api(consumer_key=CONSUMER_KEY,
                  consumer_secret=CONSUMER_SECRET,
                  access_token_key=ACCESS_TOKEN,
                  access_token_secret=ACCESS_TOKEN_SECRET)



def dotweet():
    epoch = int(time.time())
    margin_add = int(( epoch -1480344915 ) / 60.0 )
    margin = 2150000 + margin_add

    tweets = [
        ".@realDonaldTrump has lost the popular vote to @HillaryClinton by %s votes" % margin,
        "word on the street is @realDonaldTrump actually lost WI and MI, we'll see about PA.  lost by %s" % margin,
        ".@realDonaldTrump is poopy. trumpispoopy.com. lost by %s" % margin,
        "Can this be happiness, this terrifying freedom? @realDonaldTrump lost by %s votes" % margin,
        "Real generosity toward the future lies in giving all to the present.  @realDonaldTrump lost by %s votes" % margin,
        "There is always a philosophy for lack of courage. @realDonaldTrump lost by %s votes" % margin,
        ".@realDonaldTrump if i were you i would hate to be alone. Lost by %s votes" % margin,
        ".@realDonaldTrump how many million good men and women have died to secure the freedoms you are shitting upon? Lost by %s votes" % margin,
    ]

    tweet = random.choice(tweets)
    result = api.PostUpdate(tweet)
    pprint.pprint( result )
    time.sleep(3600)
    dotweet()


tweeting = Process(target=dotweet, args=())
tweeting.start()


from setuptools import setup,find_packages
setup(
  name = 'autotweety',
  packages = find_packages(exclude=["env"]),
  version = '0.1',
  description = 'Something that tweets',
  author = 'localhuman',
  author_email='tasaunders@gmail.com',
  url = 'https://github.com/localhuman/autotweet', # use the URL to the github repo
  download_url = 'https://github.com/localhuman/autotweet/tarball/master', # I'll explain this in a second
  keywords = ['twitter','@realDonaldTrump'], # arbitrary keywords
  classifiers = [],
  install_requires = ['python-twitter'],
)